Brown Paper Tickets - The fair-trade ticketing company.
Description: Brown Paper Tickets - The first and only fair trade ticketing company!
Keywords: ticket buy sell tickets events event registration

| View site in English, Español, or Français

| The fair-trade ticketing company. |
Sign Me Up! | | | Log In |
Go | Forget your login?

Find An Event | Create Your Event | Help

Create An Account
EMAIL ADDRESS
(A confirmation email will be sent to the email address provided.)
PASSWORD
(Password must be between 7 and 15 characters and contain at least one letter and one number.)
PUBLIC NAME
(This name will be displayed on your public profile page.)
COUNTRY | ZIP/POST CODE
I would like to receive daily emails with new events near me.
I would like to receive daily emails with discounted tickets near me.
ACCOUNT TYPE
| Basic Account
| Basic accounts can post comments, track purchase histories, and more!
| Event Producer
| Use this account type to create events, sell tickets, and register attendees.
| Affiliate
| Use your Affiliate Account to drive traffic to Brown Paper Tickets and you'll get paid for the tickets you help us sell.
| Developer
| Developer accounts can be used to create applications using the Brown Paper Tickets API.
| Open Ticket Network
| Sell tickets through your retail location using our Open Ticket Network.
| Media
| Members of the media can be the first to find out about new events and receive free tickets.

| Information you enter here is protected by a secure, encrypted connection. How we safeguard your privacy.

Contact us
Email
support@brownpapertickets.com
24/7 Customer Service
1-800-838-3006 US, Canada, Puerto Rico
Resources
Careers
Press
Developers
Help
Ticket Buyers
Track Your Order
Browse Events
Locations
Event Producers
Create an Event
Pricing
Services
Buy Pre-Printed Tickets
The Venue List

Join the mailing list
Get spam-free daily notifications of new events in your neighborhood!
Customize your mailing list

Connect with us

| Friend us on Facebook
| Follow us on Twitter
| Watch us on YouTube
| Read our blog
| Get to know us
| Meet the Doers

Use of Brown Paper Tickets is subject to our Terms & Conditions. All rights reserved. © 2000-2015 | Mobile EN ES FR